"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_native_1 = require("react-native");
var react_1 = require("react");
var _a = react_native_1.Dimensions.get('screen'), width = _a.width, height = _a.height;
var SlideItem = function (_a) {
    var item = _a.item, ImageComponent = _a.ImageComponent, TitleComponent = _a.TitleComponent, SubtitleComponent = _a.SubtitleComponent, OutroComponent = _a.OutroComponent;
    return (<react_native_1.View style={styles.slideContainer}>
      {ImageComponent ? (<ImageComponent />) : (<react_native_1.Image source={!item.webImage ? item.img : { uri: item.webImageUri }} resizeMode="contain" style={styles.image}/>)}
      <react_native_1.View style={styles.content}>
        {TitleComponent ? (<TitleComponent />) : (<react_native_1.Text style={styles.title}>{item.title}</react_native_1.Text>)}
        {SubtitleComponent ? (<SubtitleComponent />) : (<react_native_1.Text style={styles.subtitle}>{item.subtitle}</react_native_1.Text>)}

        {OutroComponent ? (<OutroComponent />) : (<react_native_1.Text style={styles.outro}>{item.outro}</react_native_1.Text>)}
      </react_native_1.View>
    </react_native_1.View>);
};
var Pagination = function (_a) {
    var data = _a.data, scrollX = _a.scrollX;
    return (<react_native_1.View style={styles.dotContainer}>
      {data.map(function (_, idx) {
            var inputRange = [(idx - 1) * width, idx * width, (idx + 1) * width];
            var dotWidth = scrollX.interpolate({
                inputRange: inputRange,
                outputRange: [12, 30, 12],
                extrapolate: 'clamp',
            });
            var backgroundColor = scrollX.interpolate({
                inputRange: inputRange,
                outputRange: ['#ccc', '#000', '#ccc'],
                extrapolate: 'clamp',
            });
            return (<react_native_1.Animated.View key={idx.toString()} style={[styles.dot, { width: dotWidth, backgroundColor: backgroundColor }]}/>);
        })}
    </react_native_1.View>);
};
var Onboard = function (_a) {
    var onDone = _a.onDone, skipEnabled = _a.skipEnabled, ImageComponent = _a.ImageComponent, TitleComponent = _a.TitleComponent, SubtitleComponent = _a.SubtitleComponent, OutroComponent = _a.OutroComponent, backgroundColor = _a.backgroundColor, slides = _a.slides;
    var _b = (0, react_1.useState)(0), index = _b[0], setIndex = _b[1];
    var flatListRef = (0, react_1.useRef)(null);
    var scrollX = (0, react_1.useRef)(new react_native_1.Animated.Value(0)).current;
    var handleScroll = function (e) {
        react_native_1.Animated.event([
            {
                nativeEvent: {
                    contentOffset: {
                        x: scrollX,
                    },
                },
            },
        ], {
            useNativeDriver: false,
        })(e);
    };
    var handleViewableItemChanged = (0, react_1.useRef)(function (_a) {
        var viewableItems = _a.viewableItems;
        if (viewableItems[0].index !== null) {
            setIndex(viewableItems[0].index);
        }
    }).current;
    var viewabilityConfig = (0, react_1.useRef)({
        itemVisiblePercentThreshold: 50,
    }).current;
    return (<react_native_1.SafeAreaView style={[styles.container, { backgroundColor: backgroundColor }]}>
      <react_native_1.FlatList ref={flatListRef} data={slides} renderItem={function (_a) {
            var item = _a.item, index = _a.index;
            return (<SlideItem key={index.toString()} item={item} ImageComponent={ImageComponent} TitleComponent={TitleComponent} OutroComponent={OutroComponent} SubtitleComponent={SubtitleComponent}/>);
        }} horizontal={true} pagingEnabled={true} showsHorizontalScrollIndicator={false} snapToAlignment="center" onScroll={handleScroll} onViewableItemsChanged={handleViewableItemChanged} viewabilityConfig={viewabilityConfig}/>
      <Pagination data={slides} scrollX={scrollX}/>
      <react_native_1.View style={styles.buttonContainer}>
        {index === slides.length - 1 ? (<react_native_1.TouchableOpacity style={styles.button} onPress={function () { return onDone(); }}>
            <react_native_1.Text style={styles.buttonText}>Get Started</react_native_1.Text>
          </react_native_1.TouchableOpacity>) : (<react_native_1.TouchableOpacity style={styles.button} onPress={function () {
                if (flatListRef !== null && flatListRef.current !== null) {
                    flatListRef.current.scrollToIndex({
                        index: index + 1,
                        animated: true,
                    });
                }
            }}>
            <react_native_1.Text style={styles.buttonText}>Continue</react_native_1.Text>
          </react_native_1.TouchableOpacity>)}
      </react_native_1.View>
      {skipEnabled ? (<react_native_1.TouchableOpacity style={{
                position: 'absolute',
                top: 70,
                right: 20,
            }} onPress={function () {
                if (flatListRef !== null && flatListRef.current !== null) {
                    flatListRef.current.scrollToIndex({
                        index: slides.length - 1,
                        animated: true,
                    });
                }
            }}>
          <react_native_1.Text style={{ fontSize: 18 }}>Skip</react_native_1.Text>
        </react_native_1.TouchableOpacity>) : null}
    </react_native_1.SafeAreaView>);
};
exports.default = Onboard;
var styles = react_native_1.StyleSheet.create({
    container: {
        marginTop: react_native_1.Platform.OS === 'android' ? react_native_1.StatusBar.currentHeight : 0,
    },
    slideContainer: {
        width: width,
        height: height,
        alignItems: 'center',
    },
    content: {
        alignItems: 'center',
        flex: 0.4,
    },
    image: {
        width: '100%',
        flex: 0.6,
    },
    title: {
        fontSize: 24,
        fontWeight: 'bold',
        color: '#333',
    },
    subtitle: {
        fontSize: 18,
        marginVertical: 12,
        color: '#333',
    },
    outro: {
        fontWeight: 'bold',
        fontSize: 32,
        color: 'black',
    },
    dot: {
        height: 12,
        width: 12,
        backgroundColor: '#ccc',
        borderRadius: 6,
        marginHorizontal: 5,
    },
    dotContainer: {
        position: 'absolute',
        bottom: 130,
        flexDirection: 'row',
        width: '100%',
        alignItems: 'center',
        justifyContent: 'center',
    },
    buttonContainer: {
        position: 'absolute',
        bottom: 50,
        width: '100%',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'center',
    },
    button: {
        backgroundColor: '#000',
        alignItems: 'center',
        justifyContent: 'center',
        paddingVertical: 15,
        paddingHorizontal: 100,
        borderRadius: 99,
    },
    buttonText: {
        color: '#fff',
        fontSize: 20,
        fontWeight: 'bold',
        textTransform: 'uppercase',
    },
});
